@@ -43,6 +43,7 @@ type BrowseOptions struct {
 	ReleasesFlag    bool
 	SettingsFlag    bool
 	WikiFlag        bool
+	ActionsFlag     bool
 	NoBrowserFlag   bool
 	HasRepoOverride bool
 }
@@ -69,32 +70,32 @@ func NewCmdBrowse(f *cmdutil.Factory, runF func(*BrowseOptions) error) *cobra.Co
 			- Repository home page
 			- Repository settings
 		`),
-		Use:  "browse [<number> | <path> | <commit-SHA>]",
+		Use:  "browse [<number> | <path> | <commit-sha>]",
 		Args: cobra.MaximumNArgs(1),
 		Example: heredoc.Doc(`
+			# Open the home page of the current repository
 			$ gh browse
-			#=> Open the home page of the current repository
 
+			# Open the script directory of the current repository
 			$ gh browse script/
-			#=> Open the script directory of the current repository
 
+			# Open issue or pull request 217
 			$ gh browse 217
-			#=> Open issue or pull request 217
 
+			# Open commit page
 			$ gh browse 77507cd94ccafcf568f8560cfecde965fcfa63
-			#=> Open commit page
 
+			# Open repository settings
 			$ gh browse --settings
-			#=> Open repository settings
 
+			# Open main.go at line 312
 			$ gh browse main.go:312
-			#=> Open main.go at line 312
 
+			# Open main.go with the repository at head of bug-fix branch
 			$ gh browse main.go --branch bug-fix
-			#=> Open main.go with the repository at head of bug-fix branch
 
+			# Open main.go with the repository at commit 775007cd
 			$ gh browse main.go --commit=77507cd94ccafcf568f8560cfecde965fcfa63
-			#=> Open main.go with the repository at commit 775007cd
 		`),
 		Annotations: map[string]string{
 			"help:arguments": heredoc.Doc(`
@@ -116,24 +117,26 @@ func NewCmdBrowse(f *cmdutil.Factory, runF func(*BrowseOptions) error) *cobra.Co
 			}
 
 			if err := cmdutil.MutuallyExclusive(
-				"arguments not supported when using `--projects`, `--releases`, `--settings`, or `--wiki`",
+				"arguments not supported when using `--projects`, `--releases`, `--settings`, `--actions` or `--wiki`",
 				opts.SelectorArg != "",
 				opts.ProjectsFlag,
 				opts.ReleasesFlag,
 				opts.SettingsFlag,
 				opts.WikiFlag,
+				opts.ActionsFlag,
 			); err != nil {
 				return err
 			}
 
 			if err := cmdutil.MutuallyExclusive(
-				"specify only one of `--branch`, `--commit`, `--projects`, `--releases`, `--settings`, or `--wiki`",
+				"specify only one of `--branch`, `--commit`, `--projects`, `--releases`, `--settings`, `--actions` or `--wiki`",
 				opts.Branch != "",
 				opts.Commit != "",
 				opts.ProjectsFlag,
 				opts.ReleasesFlag,
 				opts.SettingsFlag,
 				opts.WikiFlag,
+				opts.ActionsFlag,
 			); err != nil {
 				return err
 			}
@@ -158,6 +161,7 @@ func NewCmdBrowse(f *cmdutil.Factory, runF func(*BrowseOptions) error) *cobra.Co
 	cmd.Flags().BoolVarP(&opts.ProjectsFlag, "projects", "p", false, "Open repository projects")
 	cmd.Flags().BoolVarP(&opts.ReleasesFlag, "releases", "r", false, "Open repository releases")
 	cmd.Flags().BoolVarP(&opts.WikiFlag, "wiki", "w", false, "Open repository wiki")
+	cmd.Flags().BoolVarP(&opts.ActionsFlag, "actions", "a", false, "Open repository actions")
 	cmd.Flags().BoolVarP(&opts.SettingsFlag, "settings", "s", false, "Open repository settings")
 	cmd.Flags().BoolVarP(&opts.NoBrowserFlag, "no-browser", "n", false, "Print destination URL instead of opening the browser")
 	cmd.Flags().StringVarP(&opts.Commit, "commit", "c", "", "Select another commit by passing in the commit SHA, default is the last commit")
@@ -223,6 +227,8 @@ func parseSection(baseRepo ghrepo.Interface, opts *BrowseOptions) (string, error
 		return "settings", nil
 	} else if opts.WikiFlag {
 		return "wiki", nil
+	} else if opts.ActionsFlag {
+		return "actions", nil
 	}
 
 	ref := opts.Branch
